*Replication file for "Gender, Competition and Performance: Evidence from Chess Players"
*Quantitative Econmoics
*File prepared 8 June 2022
*This file produces all the results reported in the paper. 
*Data file used is called "Gender, Competition and Performance.dta"

/*
Note that when running the reghdfe command, in many cases the warning “WARNING: Singleton observations not dropped, statistical significance is biased.” appears. 

This issue is an artefact of how long ago we started this paper (circa 2012). Previous versions (when we started) of the program for reghdfe (which we use for all the regression analysis) did not drop singleton observations automatically. Later version (what we use now) do drop them automatically but an option allows them to remain in. We opted for this option to keep our results consistent from one version of our paper to the next at the time the code for reghdfe was updated. In practice it makes no difference as only a handful of observations (10 to 20) are singeltons so the degrees of freedom do not change in a meaningful way when they are excluded. Point estimates and standard errors do not change by more than 0.005 in any given regression.
*/

cd "SET PATHWAY HERE"
set scheme plotplain, permanently
version 16



***************************************************************************************
*Table I: Descriptive statistics
***************************************************************************************


use "Gender, Competition and Performance.dta", clear

global controls "points elo elo_of elo_om expected_points male_o share_men age age_o  error error_o"
order $controls

g female=male==0
keep if keeper==1


estpost sum $controls if female==1
matrix meanf1=e(mean)
matrix sd1=e(sd)

estpost sum $controls if female==0
matrix meanf0=e(mean)
matrix sd0=e(sd)


estpost ttest $controls, by(female)
estadd matrix meanf1 
estadd matrix meanf0 
estadd matrix sd1 
estadd matrix sd0 

estout . using "Table 1.tex", nounstack replace cells("meanf1(fmt(2)) meanf0(fmt(2)) b(nostar fmt(2))"    " sd1(par fmt(2)) sd0(par fmt(2)) se(par([ ])fmt(2))")  ///
mlabel("Female players" "Male players" "Diff." "Std. Error" ) delimiter(&)   end(\\) label  nonum collabels(none) extracols(3)





***************************************************************************************
**Figure 1: Expected points from the Elo curve and actual points won
***************************************************************************************

use "Gender, Competition and Performance.dta", clear

g delo=elo-elo_o
su delo, d
drop if delo>500 | delo<-500
replace expected_points =1/[1+10^((elo_o-elo)/485)]
g dd=points-expected_points

su dd 
su dd if delo>0
su dd if delo<0

ttest dd==0
ttest dd==0 if delo<0
ttest dd==0 if delo>0

xtile ptile=delo, n(1000)



bys ptile: egen melox=mean(delo)
bys ptile: egen mpoint=mean(points)
bys ptile: egen mex=mean(expected_points)


bys ptile: g a=_n
su melox, d
local p5=r(p5)
local p95=r(p95)
keep if a==1
twoway (scatter mpoint melox if a==1, msymbol(circle) msize(tiny) mcolor(gs12) xline(`p5'  `p95', lp(dash) lc(gs12)) xaxis(1 2)) ///
 (scatter expected_points delo, msymbol(square) msize(tiny) mc(black)), ///
graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
ytitle("(Expected) Points", size(medium)) xtitle("Elo{sub:i}-Elo{sub:j}", size(medium)) xtitle("", size(medium) axis(2))  ///
legend(pos(6) cols(2) region(lwidth(none)) size(medium) ///
label(1 "P{sub:ig}")  label(2 "P{sub:ig}{sup:*}") label(3 "Linear prediction")) ///
xlabel(`p5' "5th percentile" `p95' "95th percentile", axis(2) labsize(medium) angle(0)) ///
xscale(lstyle(none) axis(2)) xscale(lstyle(none) axis(2))  xlabel(0 -500(200)500, axis(1)) ylabel(, labsize(medium))
graph export "Figure1.eps", replace
graph export "Figure1.jpg", replace


***************************************************************************************
*Table II: Is the gender of the opponent conditionally independent of the player’s gender?
***************************************************************************************
use "Gender, Competition and Performance.dta", clear


g delo=elo-elo_o
su delo, d //Mean difference in the Elo ratings of player and opponent
cor elo elo_o

use "Gender, Competition and Performance.dta", clear
keep if keeper==1
tetrachoric male male_o //Cor of genders
cor elo elo_o

cor male male_o 
xi: pcorr male_o  share_men male 
xi: pcorr male_o  share_men melo male 

eststo m1: xi: reghdfe male_o male, noabsorb cluster(fideid)
eststo m2: xi: reghdfe male_o share_men male, noabsorb cluster(fideid ) 
eststo m3: xi: reghdfe male_o melo share_men male, noabsorb cluster(fideid ) 

global output "replace cells(b(fmt(3)) se(par fmt(3)))  style(fixed)   keep(male melo share_men)  delimiter(&) end(\\)   varlabels(share_men "Event share male" male "Player is male" elo "$ Elo_{i} $" elo_o "$ Elo_{j} $"  expected_points "$ P^{*} $" ) varwidth(20) stats(N r2_a, fmt(0 2) labels("\hline Games" " $ R^2 $")) "
estout m1 m2 m3 using "Table 2.tex", $output collabels(none) mlabels(none) modelwidth(50)




***************************************************************************************
*Figure 2 and Table B.I: The effect of opponent’s gender on the points a player earns
***************************************************************************************
use "Gender, Competition and Performance.dta", clear


keep if keeper==1

eststo m1: xi: reghdfe points male_o , absorb(fideid) cluster(fideid) 

eststo m2: xi: reghdfe points male_o  expected_points share_men melo, absorb( fideid age_o) cluster(fideid ) 

eststo m3: xi: reghdfe points male_o  color expected_points share_men melo, absorb( age  age_o fideid  fed_o ) cluster(fideid ) keepsing

eststo m4: xi: reghdfe points male_o  color expected_points share_men melo if male==0, absorb( age  age_o fideid  fed_o  ) cluster(fideid ) keepsing

eststo m5: xi: reghdfe points male_o  color  expected_points share_men melo if male==1, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing

global output "replace cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label keep(male_o)  delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $") varwidth(40) stats(N r2_within, fmt(0 2) labels("\hline Games" " $ R^2 $")) "
estout m1 m2 m3 m4 m5 using "Table B1.tex", $output collabels(none) mlabels("Univariate" "Controls 1" "Controls 2" "Female players" "Male players" ) modelwidth(50)


global output "replace cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label keep(male_o color share_men melo expected_points)  delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" share_men "Share of event that is male" melo "") varwidth(40) stats(N r2_within, fmt(0 2) labels("\hline Games" " $ R^2 $")) "
estout m1 m2 m3 m4 m5 using "Table B1.tex", $output collabels(none) mlabels("Univariate" "Controls 1" "Controls 2" "Female players" "Male players" ) modelwidth(50) extracols(4)

coefplot m1 m2 m3 m4 m5, keep(male_o) xline(0) nolabel legend(pos(6) cols(6) region(lwidth(none)) size(small) order(8 10 12 2 4 6) ///
label(2 "Female 1")  label(4 "Female 2") label(6 "Female 3") label(8 "Male 1")  label(10 "Male 2") label(12 "Male 3")) ylabel("") ///
p1( msymbol(square)) p2( msymbol(circle)) p3( msymbol(triangle)) ///
p4( msymbol(square_hollow)) p5( msymbol(circle_hollow)) p6( msymbol(triangle_hollow)) gen(z_) replace

keep z*
drop if z_by==.
g m=_n

replace z_at=z_at-0.05 if m==2 | m==5
replace z_at=z_at-0.1 if m==3

g model="A" if m==1
replace model="B" if m==2 
replace model="C" if m>=3 

g insig=z_ll1<0 & z_ul1>0


set scheme plotplain, permanently
twoway  (rcap z_ul1 z_ll1 z_at if insig==0, lc(black) mlab(model)) ///
(rcap z_ul1 z_ll1 z_at if insig==1, lc(gs10) mlab(model)) ///
(scatter z_b z_at if m==1, mc(black) ms(circle)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==2 , mc(black) ms(square)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==3 , mc(black) ms(triangle)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==4,  ms(triangle) mc(gs10) mlabc(gs10) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==5, m(triangle) mc(black) mlab(model) mlabc(black) mlabs(medium)), ///
yline(-0.10 -0.05 0, lp(dash) lc(gs14) lstyle(minor_grid)) yline(0, lp(dash) lc(gs10) ) ytitle("Effect of opponent being male on points won") ///
 legend(off) xtitle("")  xscale(r(0.65 1.3)) xlabel(0.65 " " .7833333 "All players" 1.1666666 "Female" 1.2833334 "Male" 1.3 " ", labs(medium) notick nogrid)  ///
 graphregion(fcolor(white) ifcolor(none) color(white) lwidth(none) ) bgcolor(white) ylab(-0.15 " " -0.10 "-0.10" -0.05 "-0.05" 0, angle(0) nogrid notick labs(medium)) yscale(r(-0.12 0))
graph export  "Figure2.eps", replace
graph export  "Figure2.jpg", replace

***************************************************************************************
*Figure 3 and Table B.II: Specification curve for the effect of opponent’s gender on the points a player earns
***************************************************************************************
use "Gender, Competition and Performance.dta", clear


keep if keeper==1

global abs="age age_o fed_o fideid"
global con="male_o share_men color melo"


xtile dec_delo=expected_points, n(10)
xtile dec_melo=melo, n(10)
g delo=elo-elo_o
gen neg=delo<0
g expected_points2=expected_points^2
g expected_points3=expected_points^3
g melo2=melo^2
g melo3=melo^3

eststo m3: xi: reghdfe points male_o  color expected_points share_men melo, absorb( age  age_o fideid  fed_o ) cluster(fideid ) keepsing


*Panel A: Sub-samples
global con="male_o share_men melo color expected_points"
eststo w1: xi: reghdfe points $con if mens==0 & womens==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w2: xi: reghdfe points $con if draw==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w3: xi: reghdfe points $con if games>=20, absorb( $abs ) cluster(fideid ) keepsing
eststo w4: xi: reghdfe points $con if junior==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w5: xi: reghdfe points $con if blitz==0 , absorb( $abs ) cluster(fideid ) keepsing


*Panel B: By Elo differnece
su delo, d
eststo e1: xi: reghdfe points $con if delo<=300 & delo>=-300, absorb( $abs ) cluster(fideid ) keepsing
eststo e2: xi: reghdfe points $con if delo<=200 & delo>=-200, absorb( $abs ) cluster(fideid ) keepsing
eststo e3: xi: reghdfe points $con if delo<=100 & delo>=-100, absorb( $abs ) cluster(fideid ) keepsing
eststo e4: xi: reghdfe points $con if delo<=50 & delo>=-50, absorb( $abs ) cluster(fideid ) keepsing
eststo e5: xi: reghdfe points $con if delo>=50 | delo<=-50, absorb( $abs ) cluster(fideid ) keepsing


*Panel D: Variant specification of Elo
eststo t1: xi: reghdfe points $con elo elo_o , absorb( $abs ) cluster(fideid ) keepsing
eststo t2: xi: reghdfe points male_o share_men color elo elo_o , absorb( age age_o fed_o ) cluster(fideid ) keepsing
eststo t3: xi: reghdfe points male_o share_men color  i.dec_delo i.dec_melo , absorb( $abs ) cluster(fideid ) keepsing
eststo t4: xi: reghdfe points $con  melo melo2 melo3 expected_points expected_points2 expected_points3 , absorb( $abs ) cluster(fideid ) keepsing
eststo t5: xi: reghdfe points $con expected_points neg, absorb( $abs ) cluster(fideid ) keepsing



*Panel E: Additional fixed effects

eststo f1: xi: reghdfe points $con, absorb( $abs Event ) cluster(fideid ) keepsing
eststo f2: xi: reghdfe points $con, absorb( $abs EventDate) cluster(fideid ) keepsing
eststo f3: xi: reghdfe points $con , absorb( $abs Event EventDate) cluster(fideid ) keepsing
eststo f4: xi: reghdfe points $con, absorb( $abs open open_o ) cluster(fideid ) keepsing
eststo f5: xi: reghdfe points $con, absorb( $abs Event EventDate open open_o) cluster(fideid )  keepsing


*Panel C: Levels of Elo
use "Gender, Competition and Performance.dta", clear


keep if keeper==1

xtile quin=elo, n(4)

forval i=1(1)4 {
	eststo l`i': xi: reghdfe points $con  if quin==`i', absorb( $abs ) cluster(fideid) keepsing
}
eststo l5: xi: reghdfe points $con  if elo_o>2000, absorb( $abs ) cluster(fideid) keepsing



global output " cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label   delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" ln_elo "Log $Elo_{i}$ " ln_elo "Log $Elo_{j}$ " ) varwidth(40) stats(N r2_within, fmt("%9.0fc" 2) labels("\hline Games" " $ R^2 $")) "


estout w1 w2 w3 w4 w5 using "Table B2.tex", replace $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout e1 e2 e3 e4 e5 using "Table B2.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout l1 l2 l3 l4 l5 using "Table B2.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout t1 t2 t4 t3 t5 using "Table B2.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout f1 f2 f4 f3 f5 using "Table B2.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)


coefplot w1 w2 w3 w4 w5 e1 e2 e3 e4 e5 l1 l2 l3 l4 l5 t1 t2 t4 t3 t5 f1 f2 f4 f3 f5 m3, keep(male_o)  gen(z_) replace

keep z*
drop if z_by==.
sort z_b
g m=_n
g insig=z_ll1<0 & z_ul1>0

su z_b if z_plot==26
local q=r(mean)
twoway  (rcap z_ul1 z_ll1 m if insig==0, lc(black)) ///
(rcap z_ul1 z_ll1 m if insig==1, lc(gs10) ) ///
(scatter z_b m if insig==0, mc(black) ms(circle)) ///
(scatter z_b m if insig==1, mc(gs10) ms(circle)) ///
(scatter z_b m if z_plot==26, mc(gs10) ms(square) mc(black)), ///
yline(`q', lp(dash) lc(gs10)) ///
yline(-0.10 -0.05 0, lp(dash) lc(gs14) lstyle(minor_grid))  ytitle("Effect of opponent being male on points won") ///
 legend(off) xtitle("")  xscale(r(0 26)) xlabel(0 " " 26 " ",  notick nogrid)  ///
 graphregion(fcolor(white) ifcolor(none)) ylab(-0.12 " " -0.10 0 -0.05 0 `q' "`=ustrunescape("\u03B2\u0302")'", labs(medium) angle(0) nogrid) yscale(r(-0.12 0))   
graph export  "Figure3.eps", replace
graph export  "Figure3.jpg", replace





*************************************************************************************
*Figure 4 and Table B.III: The effect of opponent’s gender on a player’s quality of play
*************************************************************************************
use "Gender, Competition and Performance.dta", clear

xtset fideid game
keep if keeper==1
g delo=elo-elo_o

xi: pwcorr error  l.error , sig
xi: pcorr  ln_error  l.ln_error  fideid

eststo m1: xi: reghdfe ln_error male_o if male==0, absorb(fideid) cluster(fideid) 
eststo m2: xi: reghdfe ln_error color expected_points melo share_men male_o if male==0, absorb(  age age_o fideid  fed_o ) cluster(fideid ) keepsing
eststo m3: xi: reghdfe ln_error ln_error_o color expected_points melo share_men male_o if male==0, absorb(  age age_o fideid  fed_o ) cluster(fideid ) keepsing

eststo m4: xi: reghdfe ln_error male_o if male==1, absorb(fideid) cluster(fideid) 
eststo m5: xi: reghdfe ln_error color expected_points melo share_men male_o if male==1, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing
eststo m6: xi: reghdfe ln_error ln_error_o color expected_points melo share_men male_o if male==1, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing

global abs="age age_o fed_o fideid"


global output " cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label   delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" ln_elo "Log $Elo_{i}$ " ln_elo "Log $Elo_{j}$ " ) varwidth(40) stats(N r2_a, fmt("%9.0fc" 2) labels("\hline Games" " $ R^2 $")) "
estout m1 m2 m3 m4 m5 m6 using "Table B3.tex", replace $output collabels(none) mlabels(none) modelwidth(50) keep(male_o) extracols(4)


global output "replace cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label keep(male_o color share_men melo expected_points)  delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" share_men "Share of event that is male" melo "") varwidth(40) stats(N r2_within, fmt("%9.0fc" 2) labels("\hline Games" " $ R^2 $")) "
estout m1 m2 m3 m4 m5 m6 using "Table B3.tex", $output collabels(none) mlabels("Univariate" "Controls 1" "Controls 2" "Female players" "Male players" ) modelwidth(50) extracols(4)

coefplot m1 m2 m3 m4 m5 m6, keep(male_o)  gen(z_) replace

keep z*
drop if z_by==.
g m=_n
g insig=z_ll1<0 & z_ul1>0

replace z_at=z_at-0.05 if m==2 | m==3 | m==5 | m==6
replace z_at=z_at-0.05 if  m==3 |  m==6
g model="A" if m==1 | m==4
replace model="C" if m==2 | m==5
replace model="D" if m==3 | m==6

twoway  (rcap z_ul1 z_ll1 z_at if insig==0, lc(black) mlab(model)) ///
(rcap z_ul1 z_ll1 z_at if insig==1, lc(gs10) mlab(model) mlabc(black)) ///
(scatter z_b z_at if m==1, mc(black) ms(circle)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==2 , mc(black) ms(square)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==3 , mc(black) ms(triangle)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==4,  ms(circle_hollow) mc(gs10) mlabc(gs10) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==5, m(square_hollow) mc(gs10) mlab(model) mlabc(gs10) mlabs(medium)) ///
(scatter z_b z_at if m==6, m(triangle_hollow) mc(gs10) mlab(model) mlabc(gs10) mlabs(medium)) ///
, legend(off) xtitle("")  xscale(r(0.6 1.3)) xlabel(0.6 " " .73571426 "Female players" 1.1642858 "Male players" 1.3 " ", nogrid notick labs(medium))  ///
yline(-0.05 0 0.05 0.10 0.15 0.20, lp(dash) lc(gs14) lstyle(minor_grid)) yline(0, lp(dash) lc(gs10) ) ytitle("Effect of opponent being male on average error") ///
graphregion(fcolor(white) ifcolor(none)) ylab(, angle(0) nogrid labs(medium))
graph export  "Figure4.eps", replace
graph export  "Figure4.jpg", replace




****************************************************************************************************************
*Figure 5 and Table B.IV: Specification curve for the effect of opponent’s gender on the quality of play of female players
****************************************************************************************************************

use "Gender, Competition and Performance.dta", clear


keep if keeper==1
g delo=elo-elo_o

eststo m3: xi: reghdfe ln_error ln_error_o color expected_points melo share_men male_o if male==0, absorb(  age age_o fideid  fed_o ) cluster(fideid ) keepsing


*Panel A: Sample restrictions

global con="male_o share_men melo color expected_points"
eststo w1: xi: reghdfe ln_error male_o if mens==0 & womens==0 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w2: xi: reghdfe ln_error $con if draw==0 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w3: xi: reghdfe ln_error $con if games>=20 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w4: xi: reghdfe ln_error $con if junior==0 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo w5: xi: reghdfe ln_error  $con if blitz==0 & male==0 , absorb( $abs ) cluster(fideid ) keepsing


*Panel D: Variant specification of Elo
global abs="age age_o fed_o fideid"
global con="male_o share_men color melo"

xtile dec_delo=expected_points, n(10)
xtile dec_melo=melo, n(10)
gen neg=delo<0
g expected_points2=expected_points^2
g expected_points3=expected_points^3
g melo2=melo^2
g melo3=melo^3
eststo t1: xi: reghdfe ln_error $con elo elo_o if male==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo t2: xi: reghdfe ln_error male_o share_men color elo elo_o if male==0 , absorb( age age_o fed_o ) cluster(fideid ) keepsing
eststo t3: xi: reghdfe ln_error male_o share_men color  i.dec_delo i.dec_melo if male==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo t4: xi: reghdfe ln_error $con  melo melo2 melo3 expected_points expected_points2 expected_points3 if male==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo t5: xi: reghdfe ln_error $con expected_points neg if male==0 , absorb( $abs ) cluster(fideid ) keepsing



*Panel B: Elo difference
su delo, d
eststo e1: xi: reghdfe ln_error $con if delo<=300 & delo>=-300 & male==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo e2: xi: reghdfe ln_error $con if delo<=200 & delo>=-200 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo e3: xi: reghdfe ln_error $con if delo<=100 & delo>=-100 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo e4: xi: reghdfe ln_error $con if delo<=50 & delo>=-50 & male==0, absorb( $abs ) cluster(fideid ) keepsing
eststo e5: xi: reghdfe ln_error $con if delo>=50 | delo<=-50 & male==0, absorb( $abs ) cluster(fideid ) keepsing



*Panel E: Additional fixed effects
eststo f1: xi: reghdfe ln_error $con if male==0, absorb( $abs Event ) cluster(fideid ) keepsing
eststo f2: xi: reghdfe ln_error $con if male==0, absorb( $abs EventDate) cluster(fideid ) keepsing
eststo f3: xi: reghdfe ln_error $con if male==0, absorb( $abs Event EventDate) cluster(fideid ) keepsing
eststo f4: xi: reghdfe ln_error $con if male==0, absorb( $abs open open_o ) cluster(fideid ) keepsing
eststo f5: xi: reghdfe ln_error $con if male==0, absorb( $abs Event EventDate open open_o) cluster(fideid )  keepsing



*Panel C: Level of Elo
use "Gender, Competition and Performance.dta", clear
keep if keeper==1
global abs="age age_o fed_o fideid"
global con="male_o share_men color melo"

xtile quin=elo if male==0, n(4)

forval i=1(1)4 {
	eststo l`i': xi: reghdfe ln_error $con expected_points  if quin==`i' & male==0, absorb( $abs ) cluster(fideid) keepsing
}
eststo l5: xi: reghdfe ln_error $con  if elo_o>2000 & male==0, absorb( $abs ) cluster(fideid) keepsing





global output " cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label   delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" ln_elo "Log $Elo_{i}$ " ln_elo "Log $Elo_{j}$ " ) varwidth(40) stats(N r2_a, fmt("%9.0fc" 2) labels("\hline Games" " $ R^2 $")) "
estout w1 w2 w3 w4 w5 using "Table B4.tex", replace $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout e1 e2 e3 e4 e5 using "Table B4.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout l1 l2 l3 l4 l5 using "Table B4.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout t1 t2 t4 t3 t5 using "Table B4.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout f1 f2 f4 f3 f5 using "Table B4.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)




coefplot w1 w2 w3 w4 w5 e1 e2 e3 e4 e5 l1 l2 l3 l4 l5 t1 t2 t4 t3 t5 f1 f2 f4 f3 f5 m3, keep(male_o)  gen(z_) replace

keep z*
drop if z_by==.
sort z_b
g m=_n
g insig=z_ll1<0 & z_ul1>0

su z_b if z_plot==26
local q=r(mean)
twoway  (rcap z_ul1 z_ll1 m if insig==0, lc(black)) ///
(rcap z_ul1 z_ll1 m if insig==1, lc(gs10) ) ///
(scatter z_b m if insig==0, mc(black) ms(circle)) ///
(scatter z_b m if insig==1, mc(gs10) ms(circle)) ///
(scatter z_b m if z_plot==26, mc(gs10) ms(square) mc(black)), ///
yline(`q', lp(dash) lc(gs10)) ///
yline(-0.25 0 0.25 0.5, lp(dash) lc(gs14) lstyle(minor_grid))  ytitle("Effect of opponent being male on mean error") ///
 legend(off) xtitle("")  xscale(r(0 26)) xlabel(0 " " 26 " ",  notick nogrid)  /// ///
 graphregion(fcolor(white) ifcolor(none)) ylab(-0.25 0 0.25 0.5 `q' "`=ustrunescape("\u03B2\u0302")'", labs(medium) angle(0) nogrid) yscale(r(-0.12 0)) 
graph export  "Figure5.eps", replace
graph export  "Figure5.jpg", replace




*************************************************************************************
*Figure 6 and Table B.V: The effect of opponent’s gender on the number of moves to resignation
*************************************************************************************
use "Gender, Competition and Performance.dta", clear
keep if keeper==1

ttest nmoves if (gendercomp=="mm" | gendercomp=="ff") & arranged_draw==0, by(gendercomp) 


eststo m1: xi: reghdfe ln_nmoves male_o if resign==1 & male==0, absorb(fideid) cluster(fideid) keepsing
eststo m2: xi: reghdfe ln_nmoves color expected_points melo share_men male_o  if resign==1 & male==0, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing
eststo m3: xi: reghdfe ln_nmoves ln_error_o ln_error color expected_points melo share_men male_o  if resign==1 & male==0, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing

eststo m4: xi: reghdfe ln_nmoves male_o if resign==1 & male==1, absorb(fideid) cluster(fideid) keepsing
eststo m5: xi: reghdfe ln_nmoves color expected_points melo share_men male_o  if resign==1 & male==1, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing
eststo m6: xi: reghdfe ln_nmoves ln_error_o ln_error color expected_points melo share_men male_o  if resign==1 & male==1, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing



global output "replace cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label keep(male_o color share_men melo expected_points)  delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" share_men "Share of event that is male" melo "") varwidth(40) stats(N r2_within, fmt("%9.0fc" 2) labels("\hline Games" " $ R^2 $")) "
estout m1 m2 m3 m4 m5 m6 using "Table B5.tex", $output collabels(none) mlabels("Univariate" "Controls 1" "Controls 2" "Female players" "Male players" ) modelwidth(50) extracols(4)


coefplot m1 m2 m3 m4 m5 m6, keep(male_o)  gen(z_) replace

keep z*
drop if z_by==.
g m=_n

g insig=z_ll1<0 & z_ul1>0

replace z_at=z_at-0.05 if m==2 | m==3 | m==5 | m==6
replace z_at=z_at-0.05 if  m==3 |  m==6
g model="A" if m==1 | m==4
replace model="C" if m==2 | m==5
replace model="E" if m==3 | m==6

twoway  (rcap z_ul1 z_ll1 z_at if insig==0, lc(black) mlab(model)) ///
(rcap z_ul1 z_ll1 z_at if insig==1, lc(gs10) mlab(model) mlabc(black)) ///
(scatter z_b z_at if m==1, mc(black) ms(circle)  mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==2 , mc(gs10) ms(square)  mlabc(gs10) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==3 , mc(gs10) ms(triangle)  mlabc(gs10) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==4,  ms(circle_hollow) mc(black) mlabc(black) mlab(model) mlabs(medium)) ///
(scatter z_b z_at if m==5, m(square_hollow) mc(black) mlab(model) mlabc(black) mlabs(medium)) ///
(scatter z_b z_at if m==6, m(triangle_hollow) mc(black) mlab(model) mlabc(black) mlabs(medium)) ///
, legend(off) xtitle("")  xscale(r(0.6 1.3)) xlabel(0.6 " " .73571426 "Female players" 1.1642858 "Male players" 1.3 " ", nogrid notick labs(medium))  ///
yline(-0.05 0 0.05 0.10 0.15 0.20, lp(dash) lc(gs14) lstyle(minor_grid)) yline(0, lp(dash) lc(gs10) ) ytitle("Effect of opponent being male on moves to resignation") yscale(titlegap(*-25)) ///
graphregion(fcolor(white) ifcolor(none)) ylab(, angle(0) nogrid labs(medium))
graph export  "Figure6.eps", replace
graph export  "Figure6.jpg", replace



**********************************************************************************************************
*Figure 7 and Table B.VI: Specification curve for the effect of opponent’s gender on the number of moves until a male player resigns
**********************************************************************************************************

use "Gender, Competition and Performance.dta", clear
keep if keeper==1
keep if resign==1 & male==1
g delo=elo-elo_o

eststo m1: xi: reghdfe ln_nmoves ln_error_o ln_error color expected_points melo share_men male_o  if resign==1 & male==1, absorb( age age_o fideid  fed_o ) cluster(fideid ) keepsing


*Panel A: Sample restrictions
global con="male_o share_men melo color expected_points"
eststo w1: xi: reghdfe ln_nmoves male_o if mens==0 & womens==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo w2: xi: reghdfe ln_nmoves $con if draw==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo w3: xi: reghdfe ln_nmoves $con if games>=20 , absorb( $abs ) cluster(fideid ) keepsing
eststo w4: xi: reghdfe ln_nmoves $con if junior==0 , absorb( $abs ) cluster(fideid ) keepsing
eststo w5: xi: reghdfe ln_nmoves  $con if blitz==0  , absorb( $abs ) cluster(fideid ) keepsing


*Panel D: Variant specification of Elo

global abs="age age_o fed_o fideid"
global con="male_o share_men color melo"

xtile dec_delo=expected_points, n(10)
xtile dec_melo=melo, n(10)
gen neg=delo<0
g expected_points2=expected_points^2
g expected_points3=expected_points^3
g melo2=melo^2
g melo3=melo^3
eststo t1: xi: reghdfe ln_nmoves $con elo elo_o  , absorb( $abs ) cluster(fideid ) keepsing
eststo t2: xi: reghdfe ln_nmoves male_o share_men color elo elo_o  , absorb( age age_o fed_o ) cluster(fideid ) keepsing
eststo t3: xi: reghdfe ln_nmoves male_o share_men color  i.dec_delo i.dec_melo  , absorb( $abs ) cluster(fideid ) keepsing
eststo t4: xi: reghdfe ln_nmoves $con  melo melo2 melo3 expected_points expected_points2 expected_points3  , absorb( $abs ) cluster(fideid ) keepsing
eststo t5: xi: reghdfe ln_nmoves $con expected_points neg  , absorb( $abs ) cluster(fideid ) keepsing



*Panel B: Elo differnece
global abs="age age_o fed_o fideid"
global con="male_o share_men color melo"
su delo, d
eststo e1: xi: reghdfe ln_nmoves $con if delo<=300 & delo>=-300  , absorb( $abs ) cluster(fideid ) keepsing
eststo e2: xi: reghdfe ln_nmoves $con if delo<=200 & delo>=-200 , absorb( $abs ) cluster(fideid ) keepsing
eststo e3: xi: reghdfe ln_nmoves $con if delo<=100 & delo>=-100 , absorb( $abs ) cluster(fideid ) keepsing
eststo e4: xi: reghdfe ln_nmoves $con if delo<=50 & delo>=-50 , absorb( $abs ) cluster(fideid ) keepsing
eststo e5: xi: reghdfe ln_nmoves $con if delo>=50 | delo<=-50 , absorb( $abs ) cluster(fideid ) keepsing



*Panel E: Additional fixed effects

eststo f1: xi: reghdfe ln_nmoves $con , absorb( $abs Event ) cluster(fideid ) keepsing
eststo f2: xi: reghdfe ln_nmoves $con , absorb( $abs EventDate) cluster(fideid ) keepsing
eststo f3: xi: reghdfe ln_nmoves $con , absorb( $abs Event EventDate) cluster(fideid ) keepsing
eststo f4: xi: reghdfe ln_nmoves $con , absorb( $abs open open_o ) cluster(fideid ) keepsing
eststo f5: xi: reghdfe ln_nmoves $con , absorb( $abs Event EventDate open open_o) cluster(fideid )  



*Panel C: Levels of Elo
use "Gender, Competition and Performance.dta", clear
keep if keeper==1
global abs="age age_o fed_o fideid"
global con="male_o share_men color melo"

xtile quin=elo if male==0, n(4)

forval i=1(1)4 {
	eststo l`i': xi: reghdfe ln_nmoves $con expected_points  if quin==`i' & male==0, absorb( $abs ) cluster(fideid) keepsing
}
eststo l5: xi: reghdfe ln_nmoves $con  if elo_o>2000 & male==0, absorb( $abs ) cluster(fideid) keepsing





global output " cells(b(fmt(3)) se(par fmt(3)))  style(fixed)  label   delimiter(&) end(\\)   varlabels( male_o "Opponent is male" color "$ i $ plays white" expected_points "$ P^{*}_{ij} $" ln_elo "Log $Elo_{i}$ " ln_elo "Log $Elo_{j}$ " ) varwidth(40) stats(N r2_a, fmt("%9.0fc" 2) labels("\hline Games" " $ R^2 $")) "
estout w1 w2 w3 w4 w5 using "Table B6.tex", replace $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout e1 e2 e3 e4 e5 using "Table B6.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout l1 l2 l3 l4 l5 using "Table B6.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout t1 t2 t4 t3 t5 using "Table B6.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)

estout f1 f2 f4 f3 f5 using "Table B6.tex", append $output collabels(none) mlabels(none) modelwidth(50) keep(male_o)




coefplot w1 w2 w3 w4 w5 e1 e2 e3 e4 e5 l1 l2 l3 l4 l5 t1 t2 t4 t3 t5 f1 f2 f4 f3 f5 m1, keep(male_o)  gen(z_) replace

keep z*
drop if z_by==.
sort z_b
g m=_n
g insig=z_ll1<0 & z_ul1>0

su z_b if z_plot==26
local q=r(mean)
twoway  (rcap z_ul1 z_ll1 m if insig==0, lc(black)) ///
(rcap z_ul1 z_ll1 m if insig==1, lc(gs10) ) ///
(scatter z_b m if insig==0, mc(black) ms(circle)) ///
(scatter z_b m if insig==1, mc(gs10) ms(circle)) ///
(scatter z_b m if z_plot==26, mc(gs10) ms(square) mc(black)), ///
yline(`q', lp(dash) lc(gs10)) ///
yline(-0.25 0 0.25 0.5, lp(dash) lc(gs14) lstyle(minor_grid))  ytitle("Effect of opponent being male on moves to resign") ///
 legend(off) xtitle("")  xscale(r(0 26)) xlabel(0 " " 26 " ",  notick nogrid)  /// ///
 graphregion(fcolor(white) ifcolor(none)) ylab(-0.50 -0.25 0 0.25 0.5 0.75 `q' "`=ustrunescape("\u03B2\u0302")'", labs(medium) angle(0) nogrid) yscale(r(-0.12 0)) 
graph export  "Figure7.eps", replace
graph export  "Figure7.jpg", replace





**********************************************************************************************************
*Table A.I: Percentage of game outcomes for player i by the gender composition of the game
**********************************************************************************************************
use "Gender, Competition and Performance.dta", clear

keep if keeper==1
drop if arranged

g gendercomp2="Female-Female" if gendercomp=="ff"
replace gendercomp2="Female-Male" if gendercomp=="fm"
replace gendercomp2="Male-Male" if gendercomp=="mm"
replace gendercomp2="Male-Female" if gendercomp=="mf"

tabout gendercomp2 points using "draws.txt", replace cell(row)  style(tex) ///
clab(Loss Draw Win)

*Table then needs some re-formatting to match the paper
